# Viper
A modern testing framework.

## Installation
To install, run `pip3 install viper-tests`, or `python -m pip install viper-tests` if the former gives you an error.

## Documentation
The documentation is on [a public GitHub gist](https://gist.github.com/et-sollertis-animi/8bcf48bb88c10c5a2e1a83bd39784ebf)

## Copyrighted
Copyright &copy; 2020-2021 Aarush Gupta